@@ -52,131 +52,6 @@ IntegerVector samplewithoutreplace(IntegerVector yy,int size){
 
 
 
-// function to perform the Sammon's Non-Linear Mapping.
-// The source code is from the R package MASS written by Brian Ripley, Bill Venables, 
-// Douglas M. Bates, Kurt Hornik, Albrecht Gebhardt, David Firth.
-// The maintainer is	Brian Ripley <ripley at stats.ox.ac.uk>
-
-void VR_sammon(double *dd, Sint *nn, Sint *kd, double *Y, Sint *niter,
-               double *stress, Sint *trace, double *aa, double *tol)
-{
-  int   i, j, k, m, n = *nn, nd = *kd;
-  double *xu, *xv, *e1, *e2;
-  double dpj, dq, dr, dt;
-  double xd, xx;
-  double e, epast, eprev, tot, d, d1, ee, magic = *aa;
-  
-  xu = Calloc(nd * n, double);
-  xv = Calloc(nd, double);
-  e1 = Calloc(nd, double);
-  e2 = Calloc(nd, double);
-  
-  epast = eprev = 1.0;
-  
-  /* Error in distances */
-  e = tot = 0.0;
-  for (j = 1; j < n; j++){
-    for (k = 0; k < j; k++) {
-      d = dd[k * n + j];
-      if (ISNAN(d)) continue;
-      tot += d;
-      d1 = 0.0;
-      for (m = 0; m < nd; m++) {
-        xd = Y[j + m * n] - Y[k + m * n];
-        d1 += xd * xd;
-      }
-      ee = d - sqrt(d1);
-      //   if(d1 == 0) error("initial configuration has duplicates");
-      e += (ee * ee / d);
-    }
-  }
-    e /= tot;
-  // if (*trace) Rprintf("Initial stress        : %7.5f\n", e);
-  epast = eprev = e;
-  
-  /* Iterate */
-  for (i = 1; i <= *niter; i++) {
-    CORRECT:
-    for (j = 0; j < n; j++) {
-      for (m = 0; m < nd; m++)
-        e1[m] = e2[m] = 0.0;
-      for (k = 0; k < n; k++) {
-        if (j == k)
-          continue;
-        dt = dd[k * n + j];
-        if (ISNAN(dt)) continue;
-        d1 = 0.0;
-        for (m = 0; m < nd; m++) {
-          xd = Y[j + m * n] - Y[k + m * n];
-          d1 += xd * xd;
-          xv[m] = xd;
-        }
-        dpj = sqrt(d1);
-        
-        /* Calculate derivatives */
-        dq = dt - dpj;
-        dr = dt * dpj;
-        for (m = 0; m < nd; m++) {
-          e1[m] += xv[m] * dq / dr;
-          e2[m] += (dq - xv[m] * xv[m] * (1.0 + dq / dpj) / dpj) / dr;
-        }
-      }
-      /* Correction */
-      for (m = 0; m < nd; m++)
-        xu[j + m * n] = Y[j + m * n] + magic * e1[m] / fabs(e2[m]);
-    }
-    
-    /* Error in distances */
-    e = 0.0;
-    for (j = 1; j < n; j++){
-      for (k = 0; k < j; k++) {
-        d = dd[k * n + j];
-        if (ISNAN(d)) continue;
-        d1 = 0.0;
-        for (m = 0; m < nd; m++) {
-          xd = xu[j + m * n] - xu[k + m * n];
-          d1 += xd * xd;
-        }
-        ee = d - sqrt(d1);
-        e += (ee * ee / d);
-      }
-    }
-      e /= tot;
-    if (e > eprev) {
-      e = eprev;
-      magic = magic * 0.2;
-      if (magic > 1.0e-3) goto CORRECT;
-      break;
-    }
-    magic *= 1.5;
-    if (magic > 0.5) magic = 0.5;
-    eprev = e;
-    
-    /* Move the centroid to origin and update */
-    for (m = 0; m < nd; m++) {
-      xx = 0.0;
-      for (j = 0; j < n; j++)
-        xx += xu[j + m * n];
-      xx /= n;
-      for (j = 0; j < n; j++)
-        Y[j + m * n] = xu[j + m * n] - xx;
-    }
-    
-    if (i % 10 == 0) {
-      if (e > epast - *tol)
-        break;
-      epast = e;
-    }
-  }
-  *stress = e;
-  Free(xu);
-  Free(xv);
-  Free(e1);
-  Free(e2);
-}
-
-
-
 arma::uvec which(LogicalVector x) {
   int a=std::accumulate(x.begin(),x.end(), 0.0);
 
@@ -455,29 +330,6 @@ arma::mat knn_kodama_r(arma::mat Xtrain,arma::vec Ytrain,arma::mat Xtest,int k,i
 }
 
 
-// [[Rcpp::export]]
-arma::mat samm_cpp(arma::mat x,arma::mat y,int k){
-  double* X = x.memptr();
-  double* Y = y.memptr();
-  int nn=x.n_rows;
-  int niter=100;
-  double e[1]; e[0]=0;
-  int trace=1;
-  double magic=0.2;
-  double tol=0.0001;
-
-  VR_sammon(X, &nn, &k, Y, &niter,e, &trace, &magic, &tol);
-  
-  arma::mat result(nn,k);
-  for(int j=0;j<nn;j++){
-    for(int i=0;i<k;i++){
-      result(j,i)=Y[i*nn+j];
-    }
-  }
-  return result;
-}
-
-
 
 // [[Rcpp::export]]
 arma::ivec KNNCV(arma::mat x,arma::ivec cl,arma::ivec constrain,int k) {
@@ -1808,91 +1660,3 @@ List corecpp(arma::mat x,
 }
 
 
-// [[Rcpp::export]]
-List another(arma::mat pptrain,arma::mat xtrain,
-             arma::mat xtest,arma::mat res,
-             arma::mat Xlink,double epsilon) {
-  
-  int kkk=5;
-  double* knndata = xtrain.memptr();
-  double* query = xtest.memptr();
-  int dims=pptrain.n_cols;
-  int D=xtrain.n_cols;
-  int ND=xtrain.n_rows;
-  int NQ=xtest.n_rows;
-  int Dh=Xlink.n_rows;
-  double EPS=0;
-  int SEARCHTYPE=1;
-  int USEBDTREE=0;
-  double SQRAD=0;
-  int nn=NQ*kkk;
-  int *nn_index= new int[nn];
-  double *distances= new double[nn];
-  get_NN_2Set(knndata,query,&D,&ND,&NQ,&kkk,&EPS,&SEARCHTYPE,&USEBDTREE,&SQRAD,nn_index,distances);
-  
-  arma::mat a(NQ,kkk);
-  arma::mat b(NQ,kkk);
-  arma::mat pptest(NQ,dims);
-  for(int j=0;j<NQ;j++){
-    int jkkk=j*kkk;
-    for(int i=0;i<kkk;i++){
-      a(j,i)=nn_index[j*kkk+i];
-      int indi=nn_index[j*kkk+i];
-      double temp1=0;
-      double temp2=0;
-      for(int h=0;h<Dh;h++){
-        if(Xlink(h,j)==res(h,indi-1)) temp1++;
-                if(res(h,indi-1)==NA) temp2++;
-      }
-      temp2=Dh-temp2;
-      double ratio=(temp1/temp2);
-      a(j,i)=distances[jkkk+i]*ratio;
-      if(ratio<epsilon) temp1=0; 
-      if(temp1==0) a(j,i)=-1;
-      b(j,i)=nn_index[jkkk+i];
-    }
-    for(int g=0;g<dims;g++){
-      pptest(j,g)=pptrain(nn_index[jkkk]-1,g);
-    }
-  }
-  arma::mat best_pptest=pptest;
-  for(int j=0;j<NQ;j++){
-    double best=DBL_MAX;
-    double temp=0;
-    for(int loop=0;loop<1000;loop++){
-      double distance=0;
-        for(int i=0;i<kkk;i++){
-          double dista=0;
-          for(int g=0;g<dims;g++){
-            double tt1=(pptest(j,g)-pptrain(b(j,i)-1,g));
-            dista+=(tt1*tt1);
-          }
-          dista=sqrt(dista);
-          double tt2;
-          if(a(j,i)!=-1){
-            tt2=(dista-a(j,i));
-            distance+=abs(tt2);
-          }
-        
-        }
-        if(distance<best){
-          best_pptest.row(j)=pptest.row(j);
-          best=distance;
-          temp=distance;
-        }
-        arma::mat add;
-        add=arma::randn(dims)*temp/100;
-        pptest.row(j)=best_pptest.row(j)+add.t();
-      }
-    
-    }
-  delete [] nn_index;
-  delete [] distances;
-  return List::create(Named("distances") = a,
-                      Named("index") = b,
-                      Named("pp") = best_pptest
-  );
-  
-  
-}
-
